@@ -4,7 +4,7 @@ BEGIN {
   $Moose::Meta::Attribute::Native::Trait::Hash::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Moose::Meta::Attribute::Native::Trait::Hash::VERSION = '2.0502'; # TRIAL
+  $Moose::Meta::Attribute::Native::Trait::Hash::VERSION = '2.0900'; # TRIAL
 }
 use Moose::Role;
 
@@ -18,7 +18,7 @@ no Moose::Role;
 
 # ABSTRACT: Helper trait for HashRef attributes
 
-
+__END__
 
 =pod
 
@@ -28,7 +28,7 @@ Moose::Meta::Attribute::Native::Trait::Hash - Helper trait for HashRef attribute
 
 =head1 VERSION
 
-version 2.0502
+version 2.0900
 
 =head1 SYNOPSIS
 
@@ -110,7 +110,7 @@ This method does not accept any arguments.
 
 Returns the key/value pairs in the hash as an array of array references.
 
-  for my $pair ( $object->options->kv ) {
+  for my $pair ( $object->option_pairs ) {
       print "$pair->[0] = $pair->[1]\n";
   }
 
@@ -180,13 +180,9 @@ Moose is maintained by the Moose Cabal, along with the help of many contributors
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Infinity Interactive, Inc..
+This software is copyright (c) 2013 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
