@@ -3,7 +3,7 @@ BEGIN {
   $Moose::Meta::Method::Accessor::Native::Array::shift::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Moose::Meta::Method::Accessor::Native::Array::shift::VERSION = '2.0502'; # TRIAL
+  $Moose::Meta::Method::Accessor::Native::Array::shift::VERSION = '2.0900'; # TRIAL
 }
 
 use strict;
@@ -11,16 +11,7 @@ use warnings;
 
 use Moose::Role;
 
-with 'Moose::Meta::Method::Accessor::Native::Array::Writer' => {
-    -excludes => [
-        qw(
-            _maximum_arguments
-            _inline_capture_return_value
-            _inline_optimized_set_new_value
-            _return_value
-            )
-    ]
-};
+with 'Moose::Meta::Method::Accessor::Native::Array::Writer';
 
 sub _maximum_arguments { 0 }
 
