@@ -3,7 +3,7 @@ BEGIN {
   $Moose::Meta::Method::Accessor::Native::Hash::count::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Moose::Meta::Method::Accessor::Native::Hash::count::VERSION = '2.0502'; # TRIAL
+  $Moose::Meta::Method::Accessor::Native::Hash::count::VERSION = '2.0900'; # TRIAL
 }
 
 use strict;
@@ -13,8 +13,7 @@ use Scalar::Util qw( looks_like_number );
 
 use Moose::Role;
 
-with 'Moose::Meta::Method::Accessor::Native::Reader' =>
-    { -excludes => ['_maximum_arguments'] };
+with 'Moose::Meta::Method::Accessor::Native::Reader';
 
 sub _maximum_arguments { 0 }
 
