@@ -3,7 +3,7 @@ BEGIN {
   $Moose::Meta::Method::Accessor::Native::Hash::exists::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Moose::Meta::Method::Accessor::Native::Hash::exists::VERSION = '2.0502'; # TRIAL
+  $Moose::Meta::Method::Accessor::Native::Hash::exists::VERSION = '2.0900'; # TRIAL
 }
 
 use strict;
@@ -13,16 +13,8 @@ use Scalar::Util qw( looks_like_number );
 
 use Moose::Role;
 
-with 'Moose::Meta::Method::Accessor::Native::Reader' => {
-    -excludes => [
-        qw(
-            _minimum_arguments
-            _maximum_arguments
-            _inline_check_arguments
-            )
-    ],
-    },
-    'Moose::Meta::Method::Accessor::Native::Hash';
+with 'Moose::Meta::Method::Accessor::Native::Reader',
+     'Moose::Meta::Method::Accessor::Native::Hash';
 
 sub _minimum_arguments { 1 }
 
