@@ -3,7 +3,7 @@ BEGIN {
   $Moose::Meta::TypeConstraint::Role::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Moose::Meta::TypeConstraint::Role::VERSION = '2.0502'; # TRIAL
+  $Moose::Meta::TypeConstraint::Role::VERSION = '2.0900'; # TRIAL
 }
 
 use strict;
@@ -98,7 +98,8 @@ sub is_subtype_of {
 
     if ( not ref $type_or_name_or_role ) {
         # it might be a role
-        return 1 if Class::MOP::class_of($self->role)->does_role( $type_or_name_or_role );
+        my $class = Class::MOP::class_of($self->role);
+        return 1 if defined($class) && $class->does_role( $type_or_name_or_role );
     }
 
     my $type = Moose::Util::TypeConstraints::find_type_constraint($type_or_name_or_role);
@@ -108,7 +109,8 @@ sub is_subtype_of {
     if ( $type->isa(__PACKAGE__) ) {
         # if $type_or_name_or_role isn't a role, it might be the TC name of another ::Role type
         # or it could also just be a type object in this branch
-        return Class::MOP::class_of($self->role)->does_role( $type->role );
+        my $class = Class::MOP::class_of($self->role);
+        return defined($class) && $class->does_role( $type->role );
     } else {
         # the only other thing we are a subtype of is Object
         $self->SUPER::is_subtype_of($type);
@@ -124,7 +126,7 @@ sub create_child_type {
 
 # ABSTRACT: Role/TypeConstraint parallel hierarchy
 
-
+__END__
 
 =pod
 
@@ -134,7 +136,7 @@ Moose::Meta::TypeConstraint::Role - Role/TypeConstraint parallel hierarchy
 
 =head1 VERSION
 
-version 2.0502
+version 2.0900
 
 =head1 DESCRIPTION
 
@@ -199,13 +201,9 @@ Moose is maintained by the Moose Cabal, along with the help of many contributors
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Infinity Interactive, Inc..
+This software is copyright (c) 2013 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
